LLAMA - Loss & LAtency MAtrix — LLAMA 0.0.1a6 documentation

# LLAMA - Loss & LAtency MAtrix

L.L.A.M.A. is a deployable service which artificially produces traffic for measuring network performance between endpoints.

LLAMA uses UDP socket level operations to support multiple QoS classes. UDP datagrams are fast, efficient, and will hash across ECMP paths in large networks to uncover faults and erring interfaces. LLAMA is written in pure Python for maintainability.

Contents:

## Indices and tables

- Index
- Module Index
- Search Page